pub struct SoftwareVersion {
pub application: Version,
pub library: Version,
}Expand description
Struct representing the version information of both application and library.
Fields
application: VersionVersion of the application.
library: VersionVersion of the library.
Implementations
Sourceimpl SoftwareVersion
impl SoftwareVersion
Sourcepub fn new(
application_version: &str,
library_version: &str,
channel: VersionCode,
) -> Self
pub fn new( application_version: &str, library_version: &str, channel: VersionCode, ) -> Self
Creates a new SoftwareVersion instance from given version strings.
Sourcepub fn compare_versions(&self, incoming: &SoftwareVersion) -> bool
pub fn compare_versions(&self, incoming: &SoftwareVersion) -> bool
Compares the application and library versions with an incoming SoftwareVersion.
Use at your own risk.